@@ -52,6 +52,7 @@
 
 #include "player.h"
 #include "main_win.h"
+#include "utilities.h"
 
 extern int selected_player;
 
@@ -66,6 +67,7 @@ GstBus *bus = NULL;
 gint _gstreamer_is_running = FALSE;
 extern GtkWidget *entry;
 extern GtkWidget *playlist_box;
+extern GtkWidget *player_vbox;
 
 extern void add_playlist_file(const gchar *name);
 
@@ -89,10 +91,7 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
         if (message)
         {
           memset(message,'\0',malloc_size);
-          g_snprintf(message, malloc_size,"Error : %s",error->message);
-
-          //fprintf(stdout,"error : %s\n",message);
-          //fflush(stdout);
+          g_snprintf(message, malloc_size,_("gstreamer error: %s"),error->message);
 
           gdk_threads_enter();
           put_status_message(message);
@@ -101,7 +100,7 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
           g_free(message);
         }
       }
-      g_error_free (error);
+      g_error_free(error);
       break;
     }
     case GST_MESSAGE_WARNING:
@@ -120,10 +119,7 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
         if (message)
         {
           memset(message,'\0',malloc_size);
-          g_snprintf(message, malloc_size,"Warning: %s",error->message);
-
-          //fprintf(stdout,"warning : %s\n",message);
-          //fflush(stdout);
+          g_snprintf(message, malloc_size,_("Warning: %s"),error->message);
 
           gdk_threads_enter();
           put_status_message(message);
@@ -151,10 +147,7 @@ static gboolean bus_call (GstBus *bus, GstMessage *msg, gpointer data)
         if (message)
         {
           memset(message,'\0',malloc_size);
-          g_snprintf(message, malloc_size,"Info : %s",error->message);
-
-          //fprintf(stdout,"info : %s\n",message);
-          //fflush(stdout);
+          g_snprintf(message, malloc_size,_("Info: %s"),error->message);
 
           gdk_threads_enter();
           put_status_message(message);
@@ -392,8 +385,11 @@ void gstreamer_start()
 	//if we have started the player
   if (play)
 	{
-    //show the playlist (history)
-    gtk_widget_show(playlist_box);
+    if (! container_has_child(GTK_CONTAINER(player_vbox), playlist_box))
+    {
+      gtk_box_pack_start(GTK_BOX(player_vbox), playlist_box, TRUE, TRUE, 0);
+    }
+    gtk_widget_show_all(playlist_box);
 
 		_gstreamer_is_running = TRUE;
 		bus = gst_pipeline_get_bus (GST_PIPELINE (play));
@@ -410,7 +406,7 @@ void gstreamer_start()
 	else
 	{
 		gdk_threads_enter();
-		put_status_message(" Error: cannot create gstreamer playbin\n");
+		put_status_message(_(" error: cannot create gstreamer playbin\n"));
 		gdk_threads_leave();
 	}
 }
@@ -445,26 +441,26 @@ void gstreamer_add_files(GList *list)
   }
 
 	if (play)
-	{
-		while ((song = g_list_nth_data(list, i)) != NULL)
-		{
-			if (song)
-			{
-				//add file to playlist
-				add_playlist_file(song);
-				len_uri += strlen(song);
-				uri = malloc(sizeof(char) * len_uri);
-				g_snprintf(uri,len_uri,"file://%s",song);
-				g_object_set(G_OBJECT(play), "uri", uri, NULL);
-				if (uri)
-				{
-					g_free(uri);
-					uri = NULL;
-				}
-			}
-			i++;
-		}
-	}
+  {
+    while ((song = g_list_nth_data(list, i)) != NULL)
+    {
+      if (song)
+      {
+        //add file to playlist
+        add_playlist_file(song);
+        len_uri += strlen(song);
+        uri = malloc(sizeof(char) * len_uri);
+        g_snprintf(uri,len_uri,"file://%s",song);
+        g_object_set(G_OBJECT(play), "uri", uri, NULL);
+        if (uri)
+        {
+          g_free(uri);
+          uri = NULL;
+        }
+      }
+      i++;
+    }
+  }
 }
 
 //sets volume
@@ -658,7 +654,6 @@ void gstreamer_quit()
   }
   _gstreamer_is_running = FALSE;
 
-  //hide the playlist (history)
   gtk_widget_hide(playlist_box);
 }
 
