@@ -37,6 +37,5 @@
  *********************************************************/
 
 void put_options_from_preferences();
-void split_it(guchar *fname,
-              guchar *fname_path);
+void split_it(gpointer data);
 void sigpipe_handler(gint sig);
