@@ -36,6 +36,11 @@
  *
  *********************************************************/
 
+#ifndef SPECIAL_SPLIT_H
+
+#define FILE_MODE_SINGLE 1
+#define FILE_MODE_MULTIPLE 0
+
 #define SELECTED_SPLIT_NORMAL 3
 #define SELECTED_SPLIT_TIME 2
 #define SELECTED_SPLIT_WRAP 1
@@ -46,8 +51,10 @@
 gint get_selected_split_mode(GtkToggleButton *radio_b);
 void deactivate_silence_parameters();
 void activate_silence_parameters();
-void split_mode_changed (GtkToggleButton *radio_b,
-                         gpointer data);
-void set_default_split_modes (GtkWidget *widget, 
-                              gpointer data);
+void split_mode_changed (GtkToggleButton *radio_b, gpointer data);
+void set_default_split_modes (GtkWidget *widget, gpointer data);
 GtkWidget *create_special_split_page();
+
+#define SPECIAL_SPLIT_H
+#endif
+
